import { DataSource, ViewEntity, ViewColumn } from 'typeorm';
import { InstitucionInfraccion } from '../../../institucion-infraccion/entity/institucion-infraccion.entity';
import { InstitucionUsuario } from '../../../institucion-usuario/entity/institucion-usuario.entity';
import { Multa } from '../multa.entity';
import { Operador } from '../../../operador/entity/operador.entity';
import { Prestamo } from '../../../prestamo/entity/prestamo.entity';

@ViewEntity({
  expression: (dataSource: DataSource) =>
    dataSource
      .createQueryBuilder()
      .select('mu.id_multa', 'id_multa')
      .addSelect('mu.activo', 'activo')
      .addSelect('mu.fecha_fin', 'fecha_fin')
      .addSelect('mu.id_institucion_infraccion', 'id_institucion_infraccion')
      .addSelect('mu.id_operador', 'id_operador')
      .addSelect('mu.id_prestamo', 'id_prestamo')
      .addSelect('mu.retraso', 'retraso')
      .addSelect('ii.id_infraccion', 'id_infraccion')
      .addSelect('ii.id_institucion', 'id_institucion')
      .addSelect('p.id_institucion_usuario', 'id_institucion_usuario')
      .addSelect('iu.id_usuario', 'id_usuario')
      .from(Multa, 'mu')
      .innerJoin(
        InstitucionInfraccion,
        'ii',
        'ii.id_institucion_infraccion = mu.id_institucion_infraccion',
      )
      .innerJoin(Prestamo, 'p', 'p.id_prestamo = mu.id_prestamo')
      .innerJoin(Operador, 'om', 'om.id_operador = mu.id_operador')
      .innerJoin(
        InstitucionUsuario,
        'iu',
        'iu.id_institucion_usuario = p.id_institucion_usuario',
      ),
})
export class InformacionMultaView {
  @ViewColumn()
  id_multa: number;

  @ViewColumn()
  activo: number;

  @ViewColumn()
  fecha_fin: Date;

  @ViewColumn()
  id_institucion: number;

  @ViewColumn()
  id_infraccion: number;

  @ViewColumn()
  id_institucion_infraccion: number;

  @ViewColumn()
  id_institucion_usuario: number;

  @ViewColumn()
  id_operador: number;

  @ViewColumn()
  id_prestamo: number;

  @ViewColumn()
  id_usuario: number;

  @ViewColumn()
  retraso: number;
}
